netapp_ontap.models.zapp_nvme_components_subsystem_hosts_dh_hmac_chap API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.zapp_nvme_components_subsystem_hosts_dh_hmac_chap`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class ZappNvmeComponentsSubsystemHostsDhHmacChapSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the ZappNvmeComponentsSubsystemHostsDhHmacChap object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `controller_secret_key: str POST PATCH`

    Authentication Controller Secret.

  `group_size: str GET POST PATCH`

    Authentication Diffie-Hellman Group.

    Valid choices:

    - 2048_bit
    - 3072_bit
    - 4096_bit
    - 6144_bit
    - 8192_bit
    - none
  `hash_function: str GET POST PATCH`

    Authentication Hash Function.

    Valid choices:

    - sha_256
    - sha_512
  `host_secret_key: str POST PATCH`

    Authentication Host Secret.